@@ -1,11 +1,15 @@
 #ifndef __CONFIGURATION_H_INCLUDED__
 #define __CONFIGURATION_H_INCLUDED__
 
+#if !defined(__GNUC__) && (__GNUC__ < 5) && (__STDC_VERSION__ < 201112)
+  #error "Need GCC 5 or greater, with C11 standard support, to compile!"
+#endif
+
 /* Name of package */
 #define PACKAGE "t50"
 
 /* Define to the version of this package. */
-#define PACKAGE_VERSION "5.8.2"
+#define PACKAGE_VERSION "5.8.3"
 
 /* Define to the address where bug reports for this package should be sent. */
 #define PACKAGE_BUGREPORT "t50-dev@googlegroups.com"
